==> pandoc-crossref-0.3.19-129-riscv64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-BjeaRi3v0wX6V3P7LGzgXy-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-BjeaRi3v0wX6V3P7LGzgXy-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  569fe365e7d7da422c3d8181500f1476
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-BjeaRi3v0wX6V3P7LGzgXy-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.1-CjElCeEmbPg9RMtJsMDsV0
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.2-DuROXpCSLKCIgtqKmiqc3s
    pandoc-types-1.23.1-1bQhO4167wJAXeIDmZ5obj
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-76FqlLpS4UQGwdFcdle3U6

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-DjnMGps6YyUC2tIX6cevuL
key:                  pandoc-crossref-0.3.19-DjnMGps6YyUC2tIX6cevuL
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  e5790e4e14a97db644c71471d1e52995
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-DjnMGps6YyUC2tIX6cevuL
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.2-DuROXpCSLKCIgtqKmiqc3s
    pandoc-crossref-0.3.19-BjeaRi3v0wX6V3P7LGzgXy-pandoc-crossref-internal
    pandoc-types-1.23.1-1bQhO4167wJAXeIDmZ5obj text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.19-164-riscv64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.19
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.19-75TnNwckj2zLukvyl8JxFy-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.19-75TnNwckj2zLukvyl8JxFy-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  d800926428bdb8b8544a6b61cdc6c321
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.19-75TnNwckj2zLukvyl8JxFy-pandoc-crossref-internal

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    filepath-1.4.2.2 microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-ghc-0.4.15.1-CjElCeEmbPg9RMtJsMDsV0
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pandoc-3.4-63TUATvZwvL55hlo8jfZQU
    pandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt template-haskell-2.19.0.0
    text-2.0.2 utility-ht-0.0.17.2-FHHtVV4Pxq51WmhixLkkXy

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-crossref
version:              0.3.19
visibility:           public
id:                   pandoc-crossref-0.3.19-DGAqy4P3funbvIlH6NQ4h
key:                  pandoc-crossref-0.3.19-DGAqy4P3funbvIlH6NQ4h
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  7aa6ff125db588c5c56f28ebb98c8bd7
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef Text.Pandoc.CrossRef.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-crossref-0.3.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.19-DGAqy4P3funbvIlH6NQ4h
depends:
    base-4.17.2.1 mtl-2.2.2 pandoc-3.4-63TUATvZwvL55hlo8jfZQU
    pandoc-crossref-0.3.19-75TnNwckj2zLukvyl8JxFy-pandoc-crossref-internal
    pandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX text-2.0.2

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
